@@ -24,7 +24,6 @@ def show_results(results, n=10):
 DEBUG = True
 
 template_path = pkg_resources.resource_filename('hwrt', 'templates/')
-template_path = "/home/moose/GitHub/hwrt/hwrt/templates/"
 
 # create our little application :)
 app = Flask(__name__, template_folder=template_path)
@@ -33,13 +32,15 @@ app.config.from_object(__name__)
 
 
 @app.route('/', methods=['POST', 'GET'])
-def show_entries():
+def heartbeat():
+    """Use heartbeat."""
     heartbeat = request.args.get('heartbeat', '')
     return heartbeat
 
 
 @app.route('/interactive', methods=['POST', 'GET'])
 def interactive():
+    """Interactive classifier."""
     if request.method == 'POST':
         raw_data_json = request.form['drawnJSON']
         # TODO: Check recording
@@ -59,6 +60,19 @@ def interactive():
 
 
 def get_json_result(results, n=10):
+    """Return the top ``n`` results as a json list.
+    >>> results = [{'symbolnr': 2, \
+                    'probability': 0.65, \
+                    'semantics': '\\alpha'}, \
+                   {'symbolnr': 45, \
+                    'probability': 0.25, \
+                    'semantics': '\\propto'}, \
+                   {'symbolnr': 15, \
+                    'probability': 0.0512, \
+                    'semantics': '\\varpropto'}]
+    >>> get_json_result(results, n=10)
+    [{'\\alpha': 0.65}, {'\\propto': 0.25}, {'\\varpropto': 0.0512}]
+    """
     s = []
     for res in results[:min(len(results), n)]:
         s.append({res['semantics']: res['probability']})
